@@ -107,7 +107,10 @@ class OpenBisObject():
         try:
             return self.data['permId']['permId']
         except Exception:
-            return ""
+            try:
+                return self.a.__dict__['_permId']['permId']
+            except Exception:
+                return ""
         
 
     def __getattr__(self, name):
@@ -198,6 +201,7 @@ class OpenBisObject():
             if VERBOSE: print("{} successfully updated.".format(self.entity))
             new_entity_data = get_single_item(self.permId, only_data=True)
             self._set_data(new_entity_data)
+            return self
 
 
 class Transaction:
@@ -282,6 +286,16 @@ class Transaction:
                     try:
                         resp = entity.openbis._post_request(entity.openbis.as_v3, batch_request)
                         if VERBOSE: print(f"{i+1} {entity_type}(s) {mode}d.")
+
+                        # mark every sample as not being new anymore
+                        # and add the permId attribute received by the response
+                        # we assume the response permIds are the same order as we sent them
+                        if resp:
+                            for i, resp_item in enumerate(resp):
+                                self.entities[entity_type][mode][i].a.__dict__['_is_new'] = False
+                                self.entities[entity_type][mode][i].a.__dict__['_permId'] = resp_item
+
+
                     except ValueError as err:
                         if VERBOSE: 
                             print(f"ERROR: {mode} of {i+1} {entity_type}(s) FAILED")
