@@ -1,4 +1,5 @@
 from datetime import datetime
+from pathlib import Path
 import re
 
 # display messages when in a interactive context (IPython or Jupyter)
@@ -60,7 +61,8 @@ def parse_jackson(input_json):
                     if isinstance(value, dict):
                         deref_graph(value)
                     elif isinstance(value, int):
-                        graph[key] = found[value]
+                        graph[key] = found.get(value)
+
                     elif isinstance(value, list):
                         for i, list_item in enumerate(value):
                             if isinstance(list_item, int):
@@ -253,5 +255,3 @@ def extract_userId(user):
         return user['userId']
     else:
         return str(user)
-
-
